@@ -688,6 +688,14 @@ class InsightsClient(object):
         logger.info("When specifying these items in file-redaction.yaml, they must be prefixed with 'insights.specs.default.DefaultSpecs.', i.e. 'insights.specs.default.DefaultSpecs.httpd_V'")
         logger.info("This information applies only to Insights Core collection. To use Core collection, set core_collect=True in %s", self.config.conf)
 
+    @_net
+    def checkin(self):
+        if self.config.offline:
+            logger.error('Cannot check-in in offline mode.')
+            return None
+
+        return self.connection.checkin()
+
 
 def format_config(config):
     # Log config except the password
