@@ -97,6 +97,13 @@ DEFAULT_OPTS = {
         'action': "store_true",
         'group': 'actions'
     },
+    'checkin': {
+        'default': False,
+        'opt': ['--checkin'],
+        'help': 'Do a lightweight check-in instead of full upload',
+        'action': "store_true",
+        'group': 'actions'
+    },
     'cmd_timeout': {
         # non-CLI
         'default': constants.default_cmd_timeout
@@ -527,7 +534,7 @@ class InsightsConfig(object):
                 return v
 
         # put this warning here so the error msg only prints once
-        if os.environ.get('HTTP_PROXY') and self._print_errors:
+        if os.environ.get('HTTP_PROXY') and not os.environ.get('HTTPS_PROXY') and self._print_errors:
             sys.stdout.write('WARNING: HTTP_PROXY is unused by insights-client. Please use HTTPS_PROXY.\n')
 
         # ignore these env as they are not config vars
@@ -680,6 +687,8 @@ class InsightsConfig(object):
                 raise ValueError('Cannot check registration status in offline mode.')
             if self.test_connection:
                 raise ValueError('Cannot run connection test in offline mode.')
+            if self.checkin:
+                raise ValueError('Cannot check in in offline mode.')
         if self.output_dir and self.output_file:
             raise ValueError('Specify only one: --output-dir or --output-file.')
         if self.output_dir == '':
@@ -734,7 +743,7 @@ class InsightsConfig(object):
             self.diagnosis = True
         if self.test_connection:
             self.net_debug = True
-        if self.payload or self.diagnosis or self.compliance or self.show_results or self.check_results:
+        if self.payload or self.diagnosis or self.compliance or self.check_results or self.checkin:
             self.legacy_upload = False
         if self.payload and (self.logging_file == constants.default_log_file):
             self.logging_file = constants.default_payload_log
