@@ -1,10 +1,10 @@
 import json
 
-from insights.core.evaluators import SingleEvaluator
+from insights.core.evaluators import SingleEvaluator as Evaluator
 from insights.formats import EvaluatorFormatterAdapter
 
 
-class JsonFormat(SingleEvaluator):
+class JsonFormat(Evaluator):
     def postprocess(self):
         json.dump(self.get_response(), self.stream)
 
