@@ -22,9 +22,57 @@ instances instead of a simple lookup.
 """
 import operator
 import re
+import six
+import sys
 from collections import defaultdict
-from itertools import chain
-from insights.parsr.query.boolean import All, Any, Boolean, Not, pred, pred2, TRUE
+from itertools import chain, count
+from insights.parsr.query.boolean import All, Any, Boolean, Not, pred, pred2  # noqa
+
+# intern was a builtin until it moved to sys in python3
+try:
+    intern = sys.intern
+except:
+    pass
+
+
+def _make_str(s):
+    """
+    Inspired by six.ensure_str in six version 1.15. See the six module for
+    copyright notice.
+    """
+    if six.PY2 and isinstance(s, six.text_type):
+        return s.encode("utf-8", "strict")
+    if six.PY3 and isinstance(s, six.binary_type):
+        return s.decode("utf-8", "strict")
+    return s
+
+
+# we need this when generating crumbs
+try:
+    isidentifier = str.isidentifier
+except:
+    isidentifier = re.compile(r"^[^\d\W]\w*\Z").match
+
+
+try:
+    from collections import Counter
+except ImportError:
+    from operator import itemgetter
+
+    class Counter(object):
+        def __init__(self, data):
+            self.data = defaultdict(int)
+            self.update(data)
+
+        def update(self, data):
+            for d in data:
+                self.data[d] += 1
+
+        def most_common(self, top=None):
+            res = sorted(self.data.items(), key=itemgetter(1), reverse=True)
+            return res[:top] if top is not None else res
+
+ANY = None
 
 
 class Entry(object):
@@ -34,15 +82,22 @@ class Entry(object):
     """
     __slots__ = ("_name", "attrs", "children", "parent", "lineno", "src")
 
-    def __init__(self, name=None, attrs=None, children=None, lineno=None, src=None):
-        self._name = name
-        self.attrs = attrs or []
-        self.children = children or []
+    def __init__(self, name=None, attrs=None, children=None, lineno=None, src=None, set_parents=True):
+        if type(name) is str:
+            self._name = intern(name)
+        elif isinstance(name, (six.text_type, six.binary_type)):
+            self._name = intern(_make_str(name))
+        else:
+            self._name = name
+
+        self.attrs = attrs if isinstance(attrs, (list, tuple)) else tuple()
+        self.children = children if isinstance(children, (list, tuple)) else []
         self.parent = None
         self.lineno = lineno
-        self.src = src
-        for c in self.children:
-            c.parent = self
+        self.src = src  # insights.core.Parser instance
+        if set_parents:
+            for c in self.children:
+                c.parent = self
         super(Entry, self).__init__()
 
     def __getattr__(self, name):
@@ -67,7 +122,9 @@ class Entry(object):
         """
         Returns the unique names of all the children as a list.
         """
-        return sorted(set(c.name for c in self.children))
+        return sorted(set(c._name for c in self.children if c._name))
+
+    keys = get_keys
 
     def __dir__(self):
         """
@@ -75,24 +132,80 @@ class Entry(object):
         """
         return self.get_keys() + object.__dir__(self)
 
-    def get_crumbs(self):
-        """
-        Get the unique name from the current entry to the root.
-        """
-        results = []
-        parent = self
-        while parent and parent._name is not None:
-            results.append(parent._name)
-            parent = parent.parent
+    @property
+    def source(self):
+        p = self
+        while p is not None and p.src is None:
+            p = p.parent
 
-        return ".".join(reversed(results))
+        if p is not None and p.src is not None:
+            return getattr(p.src, "file_path", p.src)
+
+    def _crumbs_up(self):
+        res = []
+        segments = []
+        cur = self
+        while cur is not None:
+            name = cur._name
+            if name is not None:
+                segments.append(name)
+            cur = cur.parent
+
+        if len(segments) == 0:
+            res.append("")
+        elif len(segments) == 1:
+            res.append(segments[0])
+        else:
+            segments = list(reversed(segments))
+            path = [segments[0]]
+            for r in segments[1:]:
+                r = "." + r if isidentifier(r) else '["{n}"]'.format(n=r)
+                path.append(r)
+            res.append("".join(path))
+        return res
+
+    def _crumbs_down(self):
+        res = set()
+
+        def inner(node, base):
+            if node.children:
+                for c in node.children:
+                    name = str(c._name) or ""
+                    if base:
+                        if not isidentifier(name):
+                            name = '"{n}"'.format(n=name)
+                            path = base + "[" + name + "]"
+                        else:
+                            path = base + "." + name
+                    else:
+                        if not isidentifier(name):
+                            name = '"{n}"'.format(n=name)
+                            path = "[" + name + "]"
+                        else:
+                            path = name
+                    inner(c, path)
+            else:
+                res.add(base)
+
+        inner(self, "")
+        return sorted(res)
+
+    def get_crumbs(self, down=False):
+        """
+        Get the unique paths from the current entry up to the root or down
+        to all of the leaves.
+        """
+        return self._crumbs_up() if not down else self._crumbs_down()
+
+    crumbs = get_crumbs
 
     @property
     def line(self):
         """
         Returns the original first line of text that generated the ``Entry``.
+        ``None`` if the model wasn't generated by an insights parser.
         """
-        if self.src is not None:
+        if self.src is not None and self.lineno is not None:
             return self.src.content[self.lineno - 1]
 
     @property
@@ -136,10 +249,10 @@ class Entry(object):
         """
         Go up from the current node to the first node that matches query.
         """
-        pred = _desugar(query)
+        predicate = _desugar(query)
         parent = self.parent
         while parent is not None:
-            if pred.test(parent):
+            if predicate(parent):
                 return parent
             parent = parent.parent
 
@@ -166,12 +279,12 @@ class Entry(object):
         """
         Selects current nodes based on name and value queries of child nodes.
         If any immediate children match the queries, the parent is included in
-        the results. The :py:func:``where_query`` function can be used to
+        the results. The :py:func:``make_child_query`` function can be used to
         construct queries that act on the children as a whole instead of one
         at a time.
 
         Example:
-        >>> from insights.parsr.query import where_query as q
+        >>> from insights.parsr.query import make_child_query as q
         >>> from insights.parsr.query import from_dict
         >>> r = from_dict(load_config())
         >>> r = conf.status.conditions.where(q("status", "False") | q("type", "Progressing"))
@@ -182,14 +295,76 @@ class Entry(object):
         ['2019-08-04T23:17:08Z', '2019-08-04T23:32:14Z']
         """
         if isinstance(name, _EntryQuery):
-            query = name
+            query = name.to_pyfunc()
         elif isinstance(name, Boolean):
-            query = child_query(name, value)
+            query = child_query(name, value).to_pyfunc()
         elif callable(name):
-            query = SimpleQuery(pred(name))
+            def predicate(e):
+                try:
+                    return name(e)
+                except:
+                    return False
+            query = predicate
         else:
-            query = child_query(name, value)
-        return Result(children=self.children if query.test(self) else [])
+            query = child_query(name, value).to_pyfunc()
+        return Result(children=self.children if query(self) else [])
+
+    def choose(self, chooser):
+        """
+        Run a selector function on each node. It should return a tuple, each
+        element of which is some query using the node. This lets you select
+        parts of each tree in a result.
+
+        If you want to rename a field, make the element a dictionary whose
+        key is the name you want and whose value is the query.
+
+        If you want to get all the children of a particular node instead of
+        specifying them individually, use the * operator in python 3.5+ or
+        return the query with ".grandchildren" appended otherwise.
+
+        Example:
+        >>> from insights.parsr.query import make_child_query as q
+        >>> from insights.parsr.query import from_dict
+
+        >>> conf = from_dict(load_config())
+        >>> p = (q("restartCount", gt(2)) & q("ready", False))
+
+        >>> # get the name, the restartCount renamed to restart, the podIP
+        >>> # from the node's parent, and all of the children from
+        >>> # n.lastState.terminated.
+
+        >>> # for python 3.5+
+        >>> sel = lambda n: (n["name"], {"restart": n.restartCount}, n.parent.podIP, *n.lastState.terminated)
+
+        >>> # for python 2
+        >>> sel = lambda n: (n["name"], {"restart": n.restartCount}, n.parent.podIP, n.lastState.terminated.grandchildren)
+
+        >>> conf.find(ANY).where(p).choose(sel)
+        """
+        results = []
+        for c in self.children:
+            res = chooser(c)
+            res = res if isinstance(res, (list, tuple)) else (res,)
+            tmp = []
+            for r in res:
+                if isinstance(r, dict):
+                    for k, v in r.items():
+                        if isinstance(v, list):
+                            tmp.append(Entry(k, children=v, set_parents=False))
+                        else:
+                            for i in v.children:
+                                tmp.append(Entry(k, i.attrs, i.children, set_parents=False))
+                else:
+                    if isinstance(r, list):
+                        tmp.extend(r)
+                    else:
+                        if isinstance(r, _Choose):
+                            tmp.extend(r.grandchildren)
+                        else:
+                            tmp.extend(r.children)
+            if tmp:
+                results.append(Entry(children=tmp, set_parents=False))
+        return _Choose(results)
 
     @property
     def section(self):
@@ -225,7 +400,7 @@ class Entry(object):
         if isinstance(query, (int, slice)):
             return self.children[query]
         query = _desugar(query)
-        return Result(children=[c for c in self.children if query.test(c)])
+        return Result(children=[c for c in self.children if query(c)])
 
     def __bool__(self):
         return bool(self._name or self.attrs or self.children)
@@ -286,11 +461,25 @@ class Result(Entry):
         """
         return sorted(set(c.name for c in self.grandchildren))
 
-    def get_crumbs(self):
+    keys = get_keys
+
+    def get_crumbs(self, down=False):
         """
         Get the unique names from the current locations to the roots.
         """
-        return sorted(set(c.get_crumbs() for c in self.children))
+        res = chain.from_iterable(c.get_crumbs(down=down) for c in self.children)
+        return sorted(set(res))
+
+    crumbs = get_crumbs
+
+    @property
+    def sources(self):
+        res = []
+        for c in self.children:
+            src = c.source
+            if src is not None:
+                res.append(src)
+        return sorted(set(res))
 
     @property
     def line(self):
@@ -416,7 +605,7 @@ class Result(Entry):
             tmp[c.parent].append(c)
 
         results = []
-        for p, v in tmp.items():
+        for _, v in tmp.items():
             try:
                 r = v[n]
                 if isinstance(r, list):
@@ -435,12 +624,12 @@ class Result(Entry):
         """
         Selects current nodes based on name and value queries of child nodes.
         If any immediate children match the queries, the parent is included in
-        the results. The :py:func:``where_query`` function can be used to
+        the results. The :py:func:``make_child_query`` function can be used to
         construct queries that act on the children as a whole instead of one
         at a time.
 
         Example:
-        >>> from insights.parsr.query import where_query as q
+        >>> from insights.parsr.query import make_child_query as q
         >>> from insights.parsr.query import from_dict
         >>> r = from_dict(load_config())
         >>> r = conf.status.conditions.where(q("status", "False") | q("type", "Progressing"))
@@ -451,25 +640,57 @@ class Result(Entry):
         ['2019-08-04T23:17:08Z', '2019-08-04T23:32:14Z']
         """
         if isinstance(name, _EntryQuery):
-            query = name
+            query = name.to_pyfunc()
         elif isinstance(name, Boolean):
-            query = child_query(name, value)
+            query = child_query(name, value).to_pyfunc()
         elif callable(name):
-            query = SimpleQuery(pred(name))
+            def predicate(e):
+                try:
+                    return name(e)
+                except:
+                    return False
+            query = predicate
         else:
-            query = child_query(name, value)
+            query = child_query(name, value).to_pyfunc()
         results = []
         seen = set()
         for c in self.children:
-            if c not in seen and query.test(c):
+            if c not in seen and query(c):
                 results.append(c)
         return Result(children=results)
 
+    def to_df(self):
+        import pandas as pd
+
+        res = []
+        for p in self.children:
+            try:
+                d = dict((c._name, c.attrs[0]) for c in p.children if len(c.attrs) == 1)
+                res.append(d)
+            except:
+                pass
+        return pd.DataFrame(res)
+
+    def most_common(self, top=None):
+        """
+        Returns the distribution of values returned by queries that return a
+        single value for each node.
+        """
+        res = [c.attrs[0] for c in self.children if len(c.attrs) == 1]
+        return Counter(res).most_common(top)
+
     def __getitem__(self, query):
         if isinstance(query, (int, slice)):
             return self.children[query]
         query = _desugar(query)
-        return Result(children=[c for c in self.grandchildren if query.test(c)])
+        return Result(children=[c for c in self.grandchildren if query(c)])
+
+
+class _Choose(Result):
+    """
+    Marker class that allows us to detected nested calls to choose
+    """
+    pass
 
 
 class _EntryQuery(object):
@@ -485,6 +706,38 @@ class _EntryQuery(object):
     def __invert__(self):
         return _NotEntryQuery(self)
 
+    def to_pyfunc(self):
+        ver = sys.version_info
+        if ver[0] == 2 and ver[1] == 6:
+            return self.test
+
+        env = {}
+        ids = count()
+
+        def expr(b):
+            if isinstance(b, _AllEntryQuery):
+                return "(" + " and ".join(expr(p) for p in b.exprs) + ")"
+            elif isinstance(b, _AnyEntryQuery):
+                return "(" + " or ".join(expr(p) for p in b.exprs) + ")"
+            elif isinstance(b, _NotEntryQuery):
+                return "(" + "not " + expr(b.query) + ")"
+            else:
+                num = next(ids)
+                func = "func_{num}".format(num=num)
+                env[func] = b.test
+                return func + "(value)"
+
+        func = """
+def predicate(value):
+    try:
+        return {body}
+    except Exception as ex:
+        return False
+        """.format(body=expr(self))
+
+        six.exec_(func, env, env)
+        return env["predicate"]
+
 
 class _AllEntryQuery(_EntryQuery, All):
     pass
@@ -498,31 +751,20 @@ class _NotEntryQuery(_EntryQuery, Not):
     pass
 
 
-class NameQuery(_EntryQuery):
-    """
-    A query against the name of an :py:class:`Entry`.
-    """
-    def __init__(self, expr):
-        self.expr = expr
-
-    def test(self, n):
-        return self.expr.test(n.name)
-
-
 class _AllAttrQuery(_EntryQuery):
     def __init__(self, expr):
         self.expr = expr
 
-    def test(self, n):
-        return all(self.expr.test(a) for a in n.attrs)
+    def test(self, e):
+        return all(self.expr(a) for a in e.attrs)
 
 
 class _AnyAttrQuery(_EntryQuery):
     def __init__(self, expr):
         self.expr = expr
 
-    def test(self, n):
-        return any(self.expr.test(a) for a in n.attrs)
+    def test(self, e):
+        return any(self.expr(a) for a in e.attrs)
 
 
 def all_(expr):
@@ -541,36 +783,21 @@ def any_(expr):
     return _AnyAttrQuery(_desugar_attr(expr))
 
 
-class SimpleQuery(_EntryQuery):
-    """
-    Automatically used in ``Entry.where`` or ``Result.where``. ``SimpleQuery``
-    wraps a function or a lambda that will be passed each ``Entry`` of the
-    current result. The passed function should return ``True`` or ``False``.
-    """
-    def __init__(self, expr):
-        if not isinstance(expr, Boolean):
-            expr = pred(expr)
-        self.expr = expr
-
-    def test(self, node):
-        return self.expr.test(node)
-
-
 class ChildQuery(_EntryQuery):
     """
-    Returns True if any child node passes the query.
+    Returns True if any child entry passes the query.
     """
     def __init__(self, expr):
         self.expr = expr
 
-    def test(self, node):
-        return any(self.expr.test(n) for n in node.children)
+    def test(self, e):
+        return any(self.expr(n) for n in e.children)
 
 
 def child_query(name, value=None):
     """
-    Converts a query into a ChildQuery that works on all child nodes at once
-    to determine if the current node is accepted.
+    Converts a query into a ChildQuery that works on all child entries at once
+    to determine if the current entry is accepted.
     """
     q = _desugar((name, value) if value is not None else name)
     return ChildQuery(q)
@@ -581,22 +808,31 @@ make_child_query = child_query
 
 def _desugar_name(q):
     if q is None:
-        return NameQuery(TRUE)
-    if isinstance(q, NameQuery):
-        return q
+        return lambda _: True
     if isinstance(q, Boolean):
-        return NameQuery(q)
+        f = q.to_pyfunc()
+        return lambda e: f(e._name)
     if callable(q):
-        return NameQuery(pred(q))
-    return NameQuery(eq(q))
+        def predicate(e):
+            try:
+                return q(e._name)
+            except:
+                return False
+        return predicate
+    return lambda e: e._name == q
 
 
 def _desugar_attr(q):
     if isinstance(q, Boolean):
-        return q
+        return q.to_pyfunc()
     if callable(q):
-        return pred(q)
-    return eq(q)
+        def predicate(v):
+            try:
+                return q(v)
+            except:
+                return False
+        return predicate
+    return lambda v: v == q
 
 
 def _desugar_attrs(q):
@@ -606,20 +842,23 @@ def _desugar_attrs(q):
         q = q[0]
         return q if isinstance(q, _EntryQuery) else _AnyAttrQuery(_desugar_attr(q))
     else:
+        # conf[name, q0, q1] means "name and (q0 or q1 for any attribute)"
         attr_queries = [_desugar_attr(a) for a in q]
-        return _AnyAttrQuery(Any(*attr_queries))
+        return _AnyAttrQuery(lambda v: any(p(v) for p in attr_queries))
 
 
 def _desugar(q):
     if isinstance(q, _EntryQuery):
-        return q
+        return q.to_pyfunc()
     if isinstance(q, tuple):
-        q = list(q)
         name_query = _desugar_name(q[0])
         attrs_query = _desugar_attrs(q[1:])
         if attrs_query:
-            return All(name_query, attrs_query)
+            aq = attrs_query.to_pyfunc()
+            return lambda e: name_query(e) and aq(e)
         return name_query
+    if q is None:
+        return lambda _: True
     return _desugar_name(q)
 
 
@@ -628,9 +867,9 @@ def _flatten(nodes):
     Flatten the config tree into a list of nodes.
     """
     def inner(n):
-        res = [n]
-        res.extend(chain.from_iterable(inner(c) for c in n.children))
-        return res
+        yield n
+        for i in chain.from_iterable(inner(c) for c in n.children):
+            yield i
     return list(chain.from_iterable(inner(n) for n in nodes))
 
 
@@ -647,11 +886,13 @@ def compile_queries(*queries):
     are `or'd` together and that result is `anded` with the name query. Any
     query that raises an exception is treated as ``False``.
     """
+    queries = [_desugar(q) for q in queries]
+
     def match(qs, nodes):
-        q = _desugar(qs[0])
-        res = [n for n in nodes if q.test(n)]
+        q = qs[0]
         qs = qs[1:]
-        if qs:
+        res = [n for n in nodes if q(n)]
+        if qs and res:
             gc = list(chain.from_iterable(n.children for n in res))
             return match(qs, gc)
         return res
@@ -685,7 +926,7 @@ def select(query, nodes, deep=False, roots=False):
     return Result(children=top)
 
 
-def from_dict(orig):
+def from_dict(orig, src=None):
     """
     from_dict is a helper function that does its best to convert a python dict
     into a tree of :py:class:`Entry` instances that can be queried.
@@ -701,13 +942,13 @@ def from_dict(orig):
                     if isinstance(res[0], Entry):
                         result.extend(res)
                     else:
-                        result.append(Entry(name=k, attrs=res))
+                        result.append(Entry(name=k, attrs=tuple(res)))
                 else:
-                    result.append(Entry(name=k, attrs=[]))
+                    result.append(Entry(name=k))
             else:
-                result.append(Entry(name=k, attrs=[v]))
-        return result
-    return Entry(children=inner(orig))
+                result.append(Entry(name=k, attrs=(v,)))
+        return tuple(result)
+    return Entry(children=inner(orig), src=src)
 
 
 def pretty_format(root, indent=4):
