@@ -18,6 +18,7 @@ class Openshift(SpecSet):
 class Specs(SpecSet):
     abrt_ccpp_conf = RegistryPoint(filterable=True)
     abrt_status_bare = RegistryPoint()
+    alternatives_display_python = RegistryPoint()
     amq_broker = RegistryPoint(multi_output=True)
     auditctl_status = RegistryPoint()
     auditd_conf = RegistryPoint()
@@ -74,6 +75,7 @@ class Specs(SpecSet):
     cinder_conf = RegistryPoint()
     cinder_volume_log = RegistryPoint(filterable=True)
     cloud_init_custom_network = RegistryPoint()
+    cloud_cfg = RegistryPoint()
     cloud_init_log = RegistryPoint(filterable=True)
     cluster_conf = RegistryPoint(filterable=True)
     cmdline = RegistryPoint()
@@ -186,6 +188,7 @@ class Specs(SpecSet):
     getconf_page_size = RegistryPoint()
     getenforce = RegistryPoint()
     getsebool = RegistryPoint()
+    gfs2_file_system_block_size = RegistryPoint(multi_output=True)
     glance_api_conf = RegistryPoint()
     glance_api_log = RegistryPoint(filterable=True)
     glance_cache_conf = RegistryPoint()
@@ -282,6 +285,7 @@ class Specs(SpecSet):
     ksmstate = RegistryPoint()
     kubepods_cpu_quota = RegistryPoint(multi_output=True)
     lastupload = RegistryPoint(multi_output=True)
+    ld_library_path_of_pid = RegistryPoint()
     libssh_client_config = RegistryPoint(filterable=True)
     libssh_server_config = RegistryPoint(filterable=True)
     libvirtd_log = RegistryPoint(filterable=True)
@@ -297,6 +301,7 @@ class Specs(SpecSet):
     ls_docker_volumes = RegistryPoint()
     ls_edac_mc = RegistryPoint()
     ls_etc = RegistryPoint()
+    ls_ipa_idoverride_memberof = RegistryPoint()
     ls_lib_firmware = RegistryPoint()
     ls_ocp_cni_openshift_sdn = RegistryPoint()
     ls_origin_local_volumes_pods = RegistryPoint()
@@ -304,6 +309,7 @@ class Specs(SpecSet):
     ls_run_systemd_generator = RegistryPoint()
     ls_R_var_lib_nova_instances = RegistryPoint()
     ls_sys_firmware = RegistryPoint()
+    ls_usr_bin = RegistryPoint(filterable=True)
     ls_usr_lib64 = RegistryPoint(filterable=True)
     ls_usr_sbin = RegistryPoint(filterable=True)
     ls_var_lib_mongodb = RegistryPoint()
@@ -339,6 +345,7 @@ class Specs(SpecSet):
     manila_conf = RegistryPoint()
     mariadb_log = RegistryPoint(filterable=True)
     max_uid = RegistryPoint()
+    mdadm_E = RegistryPoint(multi_output=True)
     md5chk_files = RegistryPoint(multi_output=True)
     mdstat = RegistryPoint()
     meminfo = RegistryPoint()
@@ -458,6 +465,7 @@ class Specs(SpecSet):
     ovs_vsctl_show = RegistryPoint()
     ovs_vswitchd_limits = RegistryPoint()
     pacemaker_log = RegistryPoint(filterable=True)
+    package_provides_command = RegistryPoint()
     package_provides_java = RegistryPoint(multi_output=True)
     package_provides_httpd = RegistryPoint(multi_output=True)
     pam_conf = RegistryPoint()
@@ -495,6 +503,7 @@ class Specs(SpecSet):
     pulp_worker_defaults = RegistryPoint()
     puppet_ssl_cert_ca_pem = RegistryPoint()
     puppetserver_config = RegistryPoint(filterable=True)
+    puppet_ca_cert_expire_date = RegistryPoint()
     pvs_noheadings = RegistryPoint()
     pvs_noheadings_all = RegistryPoint()
     pvs = RegistryPoint()
@@ -551,7 +560,9 @@ class Specs(SpecSet):
     saphostexec_status = RegistryPoint()
     saphostexec_version = RegistryPoint()
     sat5_insights_properties = RegistryPoint()
+    satellite_content_hosts_count = RegistryPoint()
     satellite_mongodb_storage_engine = RegistryPoint()
+    satellite_non_yum_type_repos = RegistryPoint()
     satellite_version_rb = RegistryPoint()
     satellite_custom_hiera = RegistryPoint()
     scheduler = RegistryPoint(multi_output=True)
@@ -691,6 +702,7 @@ class Specs(SpecSet):
     yum_log = RegistryPoint()
     yum_repolist = RegistryPoint()
     yum_repos_d = RegistryPoint(multi_output=True)
+    yum_updateinfo = RegistryPoint()
     zdump_v = RegistryPoint()
     zipl_conf = RegistryPoint()
     sendq_socket_buffer = RegistryPoint()
