@@ -9,28 +9,35 @@ data sources that standard Insights `Parsers` resolve against.
 """
 
 import logging
-import os
 import re
+import json
+
+from grp import getgrgid
+from os import stat, listdir as os_listdir
+from pwd import getpwuid
+
+import yaml
 
 from insights.core.context import HostContext
-
 from insights.core.dr import SkipComponent
 from insights.core.plugins import datasource
-from insights.core.spec_factory import RawFileProvider
+from insights.core.spec_factory import RawFileProvider, DatasourceProvider
 from insights.core.spec_factory import simple_file, simple_command, glob_file
-from insights.core.spec_factory import first_of, foreach_collect, foreach_execute
+from insights.core.spec_factory import first_of, command_with_args
+from insights.core.spec_factory import foreach_collect, foreach_execute
 from insights.core.spec_factory import first_file, listdir
 from insights.combiners.cloud_provider import CloudProvider
 from insights.combiners.services import Services
 from insights.combiners.sap import Sap
+from insights.combiners.ps import Ps
+from insights.components.rhel_version import IsRhel8, IsRhel7, IsRhel6
+from insights.parsers.mdstat import Mdstat
+from insights.parsers.lsmod import LsMod
+from insights.combiners.satellite_version import SatelliteVersion, CapsuleVersion
+from insights.parsers.mount import Mount
 from insights.specs import Specs
 
 
-from grp import getgrgid
-from os import stat
-from pwd import getpwuid
-
-
 logger = logging.getLogger(__name__)
 
 
@@ -42,29 +49,53 @@ def get_owner(filename):
     return (name, group)
 
 
-def get_cmd_and_package_in_ps(broker, target_command):
+def _get_running_commands(broker, commands):
     """
-    Search for command in ``ps auxww`` output and determine RPM providing binary
+    Search for command in ``ps auxcww`` output and determine RPM providing binary
 
     Arguments:
         broker(dict): Current state of specs collected by Insights
-        target_command(str): Command name to search for in ps output
+        commands(str or list): Command or list of commands to search for in ps output
 
     Returns:
-        set: Set including all RPMs that provide the target command
+        list: List of the full command paths of the ``command``.
+
+    Raises:
+        Exception: Raises an exception if commands object is not a list or is empty
     """
-    ps = broker[DefaultSpecs.ps_auxww].content
+    if not commands or not isinstance(commands, list):
+        raise Exception('Commands argument must be a list object and contain at least one item')
+
+    ps_list = [broker[Ps].search(COMMAND_NAME__contains=c) for c in commands]
+    ps_cmds = [i for sub_l in ps_list for i in sub_l]
     ctx = broker[HostContext]
-    results = set()
-    for p in ps:
-        p_splits = p.split(None, 10)
-        cmd = p_splits[10].split()[0] if len(p_splits) == 11 else ''
-        which = ctx.shell_out("which {0}".format(cmd)) if target_command in os.path.basename(cmd) else None
-        resolved = ctx.shell_out("readlink -e {0}".format(which[0])) if which else None
-        pkg = ctx.shell_out("/bin/rpm -qf {0}".format(resolved[0])) if resolved else None
-        if cmd and pkg is not None:
-            results.add("{0} {1}".format(cmd, pkg[0]))
-    return results
+
+    ret = set()
+    for cmd in set(p['COMMAND_NAME'] for p in ps_cmds):
+        try:
+            which = ctx.shell_out("/usr/bin/which {0}".format(cmd))
+        except Exception:
+            continue
+        ret.add(which[0]) if which else None
+    return sorted(ret)
+
+
+def _get_package(broker, command):
+    """
+    Arguments:
+        broker(dict): Current state of specs collected by Insights
+        command(str): The full command name to get the package
+
+    Returns:
+        str: The package that provides the ``command``.
+    """
+    ctx = broker[HostContext]
+    resolved = ctx.shell_out("/usr/bin/readlink -e {0}".format(command))
+    if resolved:
+        pkg = ctx.shell_out("/usr/bin/rpm -qf {0}".format(resolved[0]))
+        if pkg:
+            return pkg[0]
+    raise SkipComponent
 
 
 def _make_rpm_formatter(fmt=None):
@@ -97,6 +128,7 @@ format_rpm = _make_rpm_formatter()
 class DefaultSpecs(Specs):
     abrt_ccpp_conf = simple_file("/etc/abrt/plugins/CCpp.conf")
     abrt_status_bare = simple_command("/usr/bin/abrt status --bare=True")
+    alternatives_display_python = simple_command("/usr/sbin/alternatives --display python")
     amq_broker = glob_file("/var/opt/amq-broker/*/etc/broker.xml")
     auditctl_status = simple_command("/sbin/auditctl -s")
     auditd_conf = simple_file("/etc/audit/auditd.conf")
@@ -104,7 +136,7 @@ class DefaultSpecs(Specs):
     avc_hash_stats = simple_file("/sys/fs/selinux/avc/hash_stats")
     avc_cache_threshold = simple_file("/sys/fs/selinux/avc/cache_threshold")
 
-    @datasource(CloudProvider)
+    @datasource(CloudProvider, HostContext)
     def is_aws(broker):
         """ bool: Returns True if this node is identified as running in AWS """
         cp = broker[CloudProvider]
@@ -116,7 +148,7 @@ class DefaultSpecs(Specs):
     aws_instance_id_pkcs7 = simple_command("/usr/bin/curl -s http://169.254.169.254/latest/dynamic/instance-identity/pkcs7 --connect-timeout 5", deps=[is_aws])
     awx_manage_check_license = simple_command("/usr/bin/awx-manage check_license")
 
-    @datasource(CloudProvider)
+    @datasource(CloudProvider, HostContext)
     def is_azure(broker):
         """ bool: Returns True if this node is identified as running in Azure """
         cp = broker[CloudProvider]
@@ -141,7 +173,7 @@ class DefaultSpecs(Specs):
     ps_ef = simple_command("/bin/ps -ef")
     ps_eo = simple_command("/usr/bin/ps -eo pid,ppid,comm")
 
-    @datasource(ps_auxww)
+    @datasource(ps_auxww, HostContext)
     def tomcat_base(broker):
         """
         Function to search the output of ``ps auxww`` to find all running tomcat
@@ -170,12 +202,11 @@ class DefaultSpecs(Specs):
     ceph_df_detail = simple_command("/usr/bin/ceph df detail -f json")
     ceph_health_detail = simple_command("/usr/bin/ceph health detail -f json")
 
-    @datasource(ps_auxww)
+    @datasource(Ps, HostContext)
     def is_ceph_monitor(broker):
         """ bool: Returns True if ceph monitor process ceph-mon is running on this node """
-        ps = broker[DefaultSpecs.ps_auxww].content
-        findall = re.compile(r"ceph\-mon").findall
-        if any(findall(p) for p in ps):
+        ps = broker[Ps]
+        if ps.search(COMMAND__contains='ceph-mon'):
             return True
         raise SkipComponent()
 
@@ -195,13 +226,91 @@ class DefaultSpecs(Specs):
     cinder_api_log = first_file(["/var/log/containers/cinder/cinder-api.log", "/var/log/cinder/cinder-api.log"])
     cinder_conf = first_file(["/var/lib/config-data/puppet-generated/cinder/etc/cinder/cinder.conf", "/etc/cinder/cinder.conf"])
     cinder_volume_log = first_file(["/var/log/containers/cinder/volume.log", "/var/log/containers/cinder/cinder-volume.log", "/var/log/cinder/volume.log"])
+    cloud_cfg_input = simple_file("/etc/cloud/cloud.cfg")
+
+    @datasource(cloud_cfg_input, HostContext)
+    def cloud_cfg(broker):
+        """This datasource provides the network configuration collected
+        from ``/etc/cloud/cloud.cfg``.
+
+        Typical content of ``/etc/cloud/cloud.cfg`` file is::
+
+            #cloud-config
+            users:
+              - name: demo
+                ssh-authorized-keys:
+                  - key_one
+                  - key_two
+                passwd: $6$j212wezy$7H/1LT4f9/N3wpgNunhsIqtMj62OKiS3nyNwuizouQc3u7MbYCarYeAHWYPYb2FT.lbioDm2RrkJPb9BZMN1O/
+
+            network:
+              version: 1
+              config:
+                - type: physical
+                  name: eth0
+                  subnets:
+                    - type: dhcp
+                    - type: dhcp6
+
+            system_info:
+              default_user:
+                name: user2
+                plain_text_passwd: 'someP@assword'
+                home: /home/user2
+
+            debug:
+              output: /var/log/cloud-init-debug.log
+              verbose: true
+
+        Note:
+            This datasource may be executed using the following command:
+
+            ``insights-cat --no-header cloud_cfg``
+
+        Example:
+
+            ``{"version": 1, "config": [{"type": "physical", "name": "eth0", "subnets": [{"type": "dhcp"}, {"type": "dhcp6"}]}]}``
+
+        Returns:
+            str: JSON string when the ``network`` parameter is configure, else nothing is returned.
+
+        Raises:
+            SkipComponent: When the path does not exist or any exception occurs.
+        """
+        relative_path = '/etc/cloud/cloud.cfg'
+        try:
+            content = broker[DefaultSpecs.cloud_cfg_input].content
+            if content:
+                content = yaml.load('\n'.join(content), Loader=yaml.SafeLoader)
+                network_config = content.get('network', None)
+                if network_config:
+                    return DatasourceProvider(content=json.dumps(network_config), relative_path=relative_path)
+        except Exception as e:
+            raise SkipComponent("Unexpected exception:{e}".format(e=str(e)))
+
+        raise SkipComponent()
+
     cloud_init_custom_network = simple_file("/etc/cloud/cloud.cfg.d/99-custom-networking.cfg")
     cloud_init_log = simple_file("/var/log/cloud-init.log")
     cluster_conf = simple_file("/etc/cluster/cluster.conf")
     cmdline = simple_file("/proc/cmdline")
-    cobbler_settings = first_file(["/etc/cobbler/settings", "/conf/cobbler/settings"])
-    cobbler_modules_conf = first_file(["/etc/cobbler/modules.conf", "/conf/cobbler/modules.conf"])
     corosync = simple_file("/etc/sysconfig/corosync")
+
+    @datasource(HostContext, [IsRhel7, IsRhel8])
+    def corosync_cmapctl_cmd_list(broker):
+        """
+        corosync-cmapctl add different arguments on RHEL7 and RHEL8.
+
+        Returns:
+            list: A list of related corosync-cmapctl commands based the RHEL version.
+        """
+        if broker.get(IsRhel7):
+            return ["/usr/sbin/corosync-cmapctl", 'corosync-cmapctl -d runtime.schedmiss.timestamp', 'corosync-cmapctl -d runtime.schedmiss.delay']
+        if broker.get(IsRhel8):
+            return ["/usr/sbin/corosync-cmapctl", '/usr/sbin/corosync-cmapctl -m stats', '/usr/sbin/corosync-cmapctl -C schedmiss']
+        raise SkipComponent()
+    corosync_cmapctl = foreach_execute(corosync_cmapctl_cmd_list, "%s")
+
     corosync_conf = simple_file("/etc/corosync/corosync.conf")
     cpu_cores = glob_file("sys/devices/system/cpu/cpu[0-9]*/online")
     cpu_siblings = glob_file("sys/devices/system/cpu/cpu[0-9]*/topology/thread_siblings_list")
@@ -243,7 +352,7 @@ class DefaultSpecs(Specs):
     dotnet_version = simple_command("/usr/bin/dotnet --version")
     dracut_kdump_capture_service = simple_file("/usr/lib/dracut/modules.d/99kdumpbase/kdump-capture.service")
 
-    @datasource()
+    @datasource(HostContext)
     def du_dirs_list(broker):
         """ Provide a list of directorys for the ``du_dirs`` spec to scan """
         return ['/var/lib/candlepin/activemq-artemis']
@@ -253,7 +362,8 @@ class DefaultSpecs(Specs):
     etc_journald_conf = simple_file(r"etc/systemd/journald.conf")
     etc_journald_conf_d = glob_file(r"etc/systemd/journald.conf.d/*.conf")
     etc_machine_id = simple_file("/etc/machine-id")
-    etc_udev_40_redhat_rules = simple_file("/etc/udev/rules.d/40-redhat.rules")
+    etc_udev_40_redhat_rules = first_file(["/etc/udev/rules.d/40-redhat.rules", "/run/udev/rules.d/40-redhat.rules",
+                                       "/usr/lib/udev/rules.d/40-redhat.rules", "/usr/local/lib/udev/rules.d/40-redhat.rules"])
     etcd_conf = simple_file("/etc/etcd/etcd.conf")
     ethernet_interfaces = listdir("/sys/class/net", context=HostContext)
     ethtool = foreach_execute(ethernet_interfaces, "/sbin/ethtool %s")
@@ -274,6 +384,29 @@ class DefaultSpecs(Specs):
     getconf_page_size = simple_command("/usr/bin/getconf PAGE_SIZE")
     getenforce = simple_command("/usr/sbin/getenforce")
     getsebool = simple_command("/usr/sbin/getsebool -a")
+
+    @datasource(Mount, [IsRhel6, IsRhel7, IsRhel8], HostContext)
+    def gfs2_mount_points(broker):
+        """
+        Function to search the output of ``mount`` to find all the gfs2 file
+        systems.
+        And only run the ``stat`` command on RHEL version that's less than
+        8.3. With 8.3 and later, the command ``blkid`` will also output the
+        block size info.
+
+        Returns:
+            list: a list of mount points of which the file system type is gfs2
+        """
+        gfs2_mount_points = []
+        if (broker.get(IsRhel6) or broker.get(IsRhel7) or
+                (broker.get(IsRhel8) and broker[IsRhel8].minor < 3)):
+            for mnt in broker[Mount]:
+                if mnt.mount_type == "gfs2":
+                    gfs2_mount_points.append(mnt.mount_point)
+        if gfs2_mount_points:
+            return gfs2_mount_points
+        raise SkipComponent
+    gfs2_file_system_block_size = foreach_execute(gfs2_mount_points, "/usr/bin/stat -fc %%s %s")
     gluster_v_info = simple_command("/usr/sbin/gluster volume info")
     gnocchi_conf = first_file(["/var/lib/config-data/puppet-generated/gnocchi/etc/gnocchi/gnocchi.conf", "/etc/gnocchi/gnocchi.conf"])
     gnocchi_metricd_log = first_file(["/var/log/containers/gnocchi/gnocchi-metricd.log", "/var/log/gnocchi/metricd.log"])
@@ -322,30 +455,19 @@ class DefaultSpecs(Specs):
     jbcs_httpd24_httpd_error_log = simple_file("/opt/rh/jbcs-httpd24/root/etc/httpd/logs/error_log")
     virt_uuid_facts = simple_file("/etc/rhsm/facts/virt_uuid.facts")
 
-    @datasource(ps_auxww)
+    @datasource(Ps, HostContext)
     def httpd_cmd(broker):
         """
-        Function to search the output of ``ps auxww`` to find all running Apache
+        Function to search the output of ``ps auxcww`` to find all running Apache
         webserver processes and extract the binary path.
 
         Returns:
             list: List of the binary paths to each running process
         """
-        ps = broker[DefaultSpecs.ps_auxww].content
-        ps_httpds = set()
-        for p in ps:
-            p_splits = p.split(None, 10)
-            if len(p_splits) >= 11:
-                cmd = p_splits[10].split()[0]
-                # Should compatible with RHEL6
-                # e.g. /usr/sbin/httpd, /usr/sbin/httpd.worker and /usr/sbin/httpd.event
-                #      and SCL's httpd24-httpd
-                if os.path.basename(cmd).startswith('httpd'):
-                    ps_httpds.add(cmd)
-        # Running multiple httpd instances on RHEL is supported
-        # https://access.redhat.com/solutions/21680
-        return list(ps_httpds)
+        return _get_running_commands(broker, ['httpd', ])
 
+    httpd_pid = simple_command("/usr/bin/pgrep -o httpd")
+    httpd_limits = foreach_collect(httpd_pid, "/proc/%s/limits")
     httpd_M = foreach_execute(httpd_cmd, "%s -M")
     httpd_V = foreach_execute(httpd_cmd, "%s -V")
     ifcfg = glob_file("/etc/sysconfig/network-scripts/ifcfg-*")
@@ -380,6 +502,20 @@ class DefaultSpecs(Specs):
     kubepods_cpu_quota = glob_file("/sys/fs/cgroup/cpu/kubepods.slice/kubepods-burstable.slice/kubepods-burstable-pod[a-f0-9_]*.slice/cpu.cfs_quota_us")
     last_upload_globs = ["/etc/redhat-access-insights/.lastupload", "/etc/insights-client/.lastupload"]
     lastupload = glob_file(last_upload_globs)
+
+    @datasource()
+    def ld_library_path_of_pid(broker):
+        pids = [p for p in sorted(os_listdir('/proc/')) if p.isdigit()]
+        llds = []
+        for p in pids:
+            with open('/proc/{0}/environ'.format(p), 'r') as fp:
+                vars = fp.read()
+                lld = [v.split('=', 1)[-1] for v in vars.split('\x00') if v.startswith('LD_LIBRARY_PATH=')]
+                llds.append("{0} {1}".format(p, lld[0])) if lld else None
+        if llds:
+            return DatasourceProvider('\n'.join(llds), relative_path='insights_commands/cat_all_PID_LD_LIBRARY_PATH')
+        raise SkipComponent
+
     libssh_client_config = simple_file("/etc/libssh/libssh_client.config")
     libssh_server_config = simple_file("/etc/libssh/libssh_server.config")
     libvirtd_log = simple_file("/var/log/libvirt/libvirtd.log")
@@ -395,6 +531,7 @@ class DefaultSpecs(Specs):
         "/etc/pki/ovirt-vmconsole", "/etc/nova/migration", "/etc/sysconfig",
         "/etc/cloud/cloud.cfg.d", "/etc/rc.d/init.d"])
     ls_etc = simple_command("/bin/ls -lan {0}".format(' '.join(etc_and_sub_dirs)))
+    ls_ipa_idoverride_memberof = simple_command("/bin/ls -lan /usr/share/ipa/ui/js/plugins/idoverride-memberof")
     ls_lib_firmware = simple_command("/bin/ls -lanR /lib/firmware")
     ls_ocp_cni_openshift_sdn = simple_command("/bin/ls -l /var/lib/cni/networks/openshift-sdn")
     ls_origin_local_volumes_pods = simple_command("/bin/ls -l /var/lib/origin/openshift.local.volumes/pods")
@@ -403,6 +540,7 @@ class DefaultSpecs(Specs):
     ls_R_var_lib_nova_instances = simple_command("/bin/ls -laR /var/lib/nova/instances")
     ls_sys_firmware = simple_command("/bin/ls -lanR /sys/firmware")
     ls_tmp = simple_command("/bin/ls -la /tmp")
+    ls_usr_bin = simple_command("/bin/ls -lan /usr/bin")
     ls_usr_lib64 = simple_command("/bin/ls -lan /usr/lib64")
     ls_var_lib_mongodb = simple_command("/bin/ls -la /var/lib/mongodb")
     ls_var_lib_nova_instances = simple_command("/bin/ls -laRZ /var/lib/nova/instances")
@@ -430,12 +568,20 @@ class DefaultSpecs(Specs):
     mariadb_log = simple_file("/var/log/mariadb/mariadb.log")
     max_uid = simple_command("/bin/awk -F':' '{ if($3 > max) max = $3 } END { print max }' /etc/passwd")
 
-    @datasource()
+    @datasource(HostContext)
     def md5chk_file_list(broker):
         """ Provide a list of files to be processed by the ``md5chk_files`` spec """
         return ["/etc/pki/product/69.pem", "/etc/pki/product-default/69.pem", "/usr/lib/libsoftokn3.so", "/usr/lib64/libsoftokn3.so", "/usr/lib/libfreeblpriv3.so", "/usr/lib64/libfreeblpriv3.so"]
     md5chk_files = foreach_execute(md5chk_file_list, "/usr/bin/md5sum %s")
     mdstat = simple_file("/proc/mdstat")
+
+    @datasource(Mdstat, HostContext)
+    def md_device_list(broker):
+        md = broker[Mdstat]
+        if md.components:
+            return [dev["device_name"] for dev in md.components if dev["active"]]
+        raise SkipComponent()
+    mdadm_E = foreach_execute(md_device_list, "/usr/sbin/mdadm -E %s")
     meminfo = first_file(["/proc/meminfo", "/meminfo"])
     messages = simple_file("/var/log/messages")
     modinfo_i40e = simple_command("/sbin/modinfo i40e")
@@ -528,10 +674,30 @@ class DefaultSpecs(Specs):
     ovirt_engine_ui_log = simple_file("/var/log/ovirt-engine/ui.log")
     ovs_vsctl_list_bridge = simple_command("/usr/bin/ovs-vsctl list bridge")
     ovs_vsctl_show = simple_command("/usr/bin/ovs-vsctl show")
+
+    @datasource(Ps, HostContext)
+    def cmd_and_pkg(broker):
+        """
+        Returns:
+            list: List of the command and provider package string of the specified commands.
+
+        Attributes:
+            COMMANDS (list): List of the specified commands that need to check the provider package.
+        """
+        COMMANDS = ['java']
+        pkg_cmd = list()
+        for cmd in _get_running_commands(broker, COMMANDS):
+            pkg_cmd.append("{0} {1}".format(cmd, _get_package(broker, cmd)))
+        if pkg_cmd:
+            return '\n'.join(pkg_cmd)
+        raise SkipComponent
+
+    package_provides_command = command_with_args("/usr/bin/echo '%s'", cmd_and_pkg)
+    package_provides_java = foreach_execute(cmd_and_pkg, "/usr/bin/echo '%s'")
     pacemaker_log = first_file(["/var/log/pacemaker.log", "/var/log/pacemaker/pacemaker.log"])
     pci_rport_target_disk_paths = simple_command("/usr/bin/find /sys/devices/ -maxdepth 10 -mindepth 9 -name stat -type f")
 
-    @datasource(Services, context=HostContext)
+    @datasource(Services, HostContext)
     def pcp_enabled(broker):
         """ bool: Returns True if pmproxy service is on in services """
         if not broker[Services].is_on("pmproxy"):
@@ -563,6 +729,7 @@ class DefaultSpecs(Specs):
     proc_snmp_ipv6 = simple_file("proc/net/snmp6")
     proc_stat = simple_file("proc/stat")
     pulp_worker_defaults = simple_file("etc/default/pulp_workers")
+    puppet_ca_cert_expire_date = simple_command("/usr/bin/openssl x509 -in /etc/puppetlabs/puppet/ssl/ca/ca_crt.pem -enddate -noout")
     pvs_noheadings = simple_command("/sbin/pvs --nameprefixes --noheadings --separator='|' -a -o pv_all,vg_name --config=\"global{locking_type=0}\"")
     qemu_conf = simple_file("/etc/libvirt/qemu.conf")
     qemu_xml = glob_file(r"/etc/libvirt/qemu/*.xml")
@@ -580,11 +747,6 @@ class DefaultSpecs(Specs):
     redhat_release = simple_file("/etc/redhat-release")
     resolv_conf = simple_file("/etc/resolv.conf")
     rhn_conf = first_file(["/etc/rhn/rhn.conf", "/conf/rhn/rhn/rhn.conf"])
-    rhn_entitlement_cert_xml = first_of([glob_file("/etc/sysconfig/rhn/rhn-entitlement-cert.xml*"),
-                                   glob_file("/conf/rhn/sysconfig/rhn/rhn-entitlement-cert.xml*")])
-    rhn_schema_version = simple_command("/usr/bin/rhn-schema-version")
-    rhn_taskomatic_daemon_log = first_file(["/var/log/rhn/rhn_taskomatic_daemon.log",
-                                               "rhn-logs/rhn/rhn_taskomatic_daemon.log"])
     rhsm_conf = simple_file("/etc/rhsm/rhsm.conf")
     rhsm_log = simple_file("/var/log/rhsm/rhsm.log")
     rhsm_releasever = simple_file('/var/lib/rhsm/cache/releasever.json')
@@ -593,15 +755,47 @@ class DefaultSpecs(Specs):
     rsyslog_conf = glob_file(["/etc/rsyslog.conf", "/etc/rsyslog.d/*.conf"])
     samba = simple_file("/etc/samba/smb.conf")
 
-    @datasource(Sap)
+    @datasource(Sap, HostContext)
     def sap_sid(broker):
+        """
+        list: List of the SID of all SAP Instances.
+        """
         sap = broker[Sap]
-        return [sap.sid(i).lower() for i in sap.local_instances]
+        return list(set(sap.sid(i).lower() for i in sap.all_instances))
 
     sap_hdb_version = foreach_execute(sap_sid, "/usr/bin/sudo -iu %sadm HDB version", keep_rc=True)
     saphostctl_getcimobject_sapinstance = simple_command("/usr/sap/hostctrl/exe/saphostctrl -function GetCIMObject -enuminstances SAPInstance")
+    saphostexec_status = simple_command("/usr/sap/hostctrl/exe/saphostexec -status")
+    saphostexec_version = simple_command("/usr/sap/hostctrl/exe/saphostexec -version")
     sat5_insights_properties = simple_file("/etc/redhat-access/redhat-access-insights.properties")
+
+    @datasource(SatelliteVersion, HostContext)
+    def is_satellite_server(broker):
+        """
+        bool: Returns True if the host is satellite server.
+        """
+        if broker[SatelliteVersion]:
+            return True
+        raise SkipComponent
+
+    @datasource(CapsuleVersion, HostContext)
+    def is_satellite_capsule(broker):
+        """
+        bool: Returns True if the host is satellite capsule.
+        """
+        if broker[CapsuleVersion]:
+            return True
+        raise SkipComponent
+
+    satellite_content_hosts_count = simple_command(
+        "/usr/bin/sudo -iu postgres /usr/bin/psql -d foreman -c 'select count(*) from hosts'",
+        deps=[is_satellite_server]
+    )
     satellite_mongodb_storage_engine = simple_command("/usr/bin/mongo pulp_database --eval 'db.serverStatus().storageEngine'")
+    satellite_non_yum_type_repos = simple_command(
+        "/usr/bin/mongo pulp_database --eval 'db.repo_importers.find({\"importer_type_id\": { $ne: \"yum_importer\"}}).count()'",
+        deps=[[is_satellite_server, is_satellite_capsule]]
+    )
     satellite_version_rb = simple_file("/usr/share/foreman/lib/satellite/version.rb")
     satellite_custom_hiera = simple_file("/etc/foreman-installer/custom-hiera.yaml")
     scsi = simple_file("/proc/scsi/scsi")
@@ -621,7 +815,20 @@ class DefaultSpecs(Specs):
     softnet_stat = simple_file("proc/net/softnet_stat")
     software_collections_list = simple_command('/usr/bin/scl --list')
     spamassassin_channels = simple_command("/bin/grep -r '^\\s*CHANNELURL=' /etc/mail/spamassassin/channel.d")
-    ss = simple_command("/usr/sbin/ss -tupna")
+
+    @datasource(LsMod, HostContext)
+    def is_mod_loaded_for_ss(broker):
+        """
+        bool: Returns True if the kernel modules required by ``ss -tupna``
+        command are loaded.
+        """
+        lsmod = broker[LsMod]
+        req_mods = ['inet_diag', 'tcp_diag', 'udp_diag']
+        if all(mod in lsmod for mod in req_mods):
+            return True
+        raise SkipComponent
+
+    ss = simple_command("/usr/sbin/ss -tupna", deps=[is_mod_loaded_for_ss])
     ssh_config = simple_file("/etc/ssh/ssh_config")
     ssh_config_d = glob_file(r"/etc/ssh/ssh_config.d/*.conf")
     ssh_foreman_proxy_config = simple_file("/usr/share/foreman-proxy/.ssh/ssh_config")
@@ -629,6 +836,7 @@ class DefaultSpecs(Specs):
     sshd_config_perms = simple_command("/bin/ls -l /etc/ssh/sshd_config")
     sssd_config = simple_file("/etc/sssd/sssd.conf")
     subscription_manager_id = simple_command("/usr/sbin/subscription-manager identity")  # use "/usr/sbin" here, BZ#1690529
+    subscription_manager_installed_product_ids = simple_command("/usr/bin/find /etc/pki/product-default/ /etc/pki/product/ -name '*pem' -exec rct cat-cert --no-content '{}' \;")
     swift_object_expirer_conf = first_file(["/var/lib/config-data/puppet-generated/swift/etc/swift/object-expirer.conf", "/etc/swift/object-expirer.conf"])
     swift_proxy_server_conf = first_file(["/var/lib/config-data/puppet-generated/swift/etc/swift/proxy-server.conf", "/etc/swift/proxy-server.conf"])
     sysconfig_kdump = simple_file("etc/sysconfig/kdump")
@@ -677,6 +885,7 @@ class DefaultSpecs(Specs):
     uptime = simple_command("/usr/bin/uptime")
     usr_journald_conf_d = glob_file(r"usr/lib/systemd/journald.conf.d/*.conf")  # note that etc_journald.conf.d also exists
     vdo_status = simple_command("/usr/bin/vdo status")
+    version_info = simple_file("/version_info")
     vgdisplay = simple_command("/sbin/vgdisplay")
     vhost_net_zero_copy_tx = simple_file("/sys/module/vhost_net/parameters/experimental_zcopytx")
     vdsm_log = simple_file("var/log/vdsm/vdsm.log")
@@ -699,6 +908,7 @@ class DefaultSpecs(Specs):
     yum_log = simple_file("/var/log/yum.log")
     yum_repolist = simple_command("/usr/bin/yum -C --noplugins repolist")
     yum_repos_d = glob_file("/etc/yum.repos.d/*.repo")
+    yum_updateinfo = simple_command("/usr/bin/yum -C updateinfo list")
     zipl_conf = simple_file("/etc/zipl.conf")
     rpm_format = format_rpm()
     installed_rpms = simple_command("/bin/rpm -qa --qf '%s'" % rpm_format, context=HostContext)
