@@ -9,6 +9,7 @@ simple_file = partial(simple_file, context=SosArchiveContext)
 
 
 class SosSpecs(Specs):
+    alternatives_display_python = simple_file("sos_commands/alternatives/alternatives_--display_python")
     auditctl_status = simple_file("sos_commands/auditd/auditctl_-s")
     autofs_conf = simple_file("/etc/autofs.conf")
 
@@ -38,6 +39,8 @@ class SosSpecs(Specs):
         ]
     )
     cni_podman_bridge_conf = simple_file("/etc/cni/net.d/87-podman-bridge.conflist")
+    cobbler_settings = first_file(["/etc/cobbler/settings", "/conf/cobbler/settings"])
+    cobbler_modules_conf = first_file(["/etc/cobbler/modules.conf", "/conf/cobbler/modules.conf"])
     corosync_cmapctl = glob_file("sos_commands/corosync/corosync-cmapctl*")
     cpe = simple_file("/etc/system-release-cpe")
     cpu_smt_control = simple_file("sys/devices/system/cpu/smt/control")
@@ -119,7 +122,9 @@ class SosSpecs(Specs):
     libvirtd_qemu_log = glob_file(r"/var/log/libvirt/qemu/*.log")
     locale = simple_file("sos_commands/i18n/locale")
     lsblk = first_file(["sos_commands/block/lsblk", "sos_commands/filesys/lsblk"])
+    lsblk_pairs = simple_file("sos_commands/block/lsblk_-O_-P")
     ls_boot = simple_file("sos_commands/boot/ls_-lanR_.boot")
+    ls_sys_firmware = simple_file("sos_commands/boot/ls_-lanR_.sys.firmware")
     lscpu = simple_file("sos_commands/processor/lscpu")
     lsinitrd = simple_file("sos_commands/boot/lsinitrd")
     lsof = simple_file("sos_commands/process/lsof_-b_M_-n_-l")
@@ -135,6 +140,7 @@ class SosSpecs(Specs):
     manila_conf = first_file(["/var/lib/config-data/puppet-generated/manila/etc/manila/manila.conf", "/etc/manila/manila.conf"])
     mistral_executor_log = simple_file("/var/log/mistral/executor.log")
     modinfo_all = glob_file("sos_commands/kernel/modinfo_*")
+    mokutil_sbstate = simple_file("sos_commands/boot/mokutil_--sb-state")
     mount = simple_file("sos_commands/filesys/mount_-l")
     mounts = simple_file("/proc/mounts")
     mlx4_port = glob_file("/sys/bus/pci/devices/*/mlx4_port[0-9]")
@@ -201,16 +207,21 @@ class SosSpecs(Specs):
     rabbitmq_report_of_containers = glob_file("sos_commands/rabbitmq/docker_exec_-t_rabbitmq-bundle-docker-*_rabbitmqctl_report")
     rabbitmq_startup_err = simple_file("/var/log/rabbitmq/startup_err")
     rhn_charsets = first_file(["sos_commands/satellite/rhn-charsets", "sos_commands/rhn/rhn-charsets"])
+    rhn_entitlement_cert_xml = first_of([glob_file("/etc/sysconfig/rhn/rhn-entitlement-cert.xml*"),
+                                   glob_file("/conf/rhn/sysconfig/rhn/rhn-entitlement-cert.xml*")])
     rhn_hibernate_conf = first_file(["/usr/share/rhn/config-defaults/rhn_hibernate.conf", "/config-defaults/rhn_hibernate.conf"])
     rhn_search_daemon_log = first_file([
         "/var/log/rhn/search/rhn_search_daemon.log",
         "/rhn-logs/rhn/search/rhn_search_daemon.log"
     ])
+    rhn_schema_version = simple_file("sos_commands/satellite/rhn-schema-version")
     rhn_server_satellite_log = simple_file("var/log/rhn/rhn_server_satellite.log")
     rhn_server_xmlrpc_log = first_file([
         "/var/log/rhn/rhn_server_xmlrpc.log",
         "/rhn-logs/rhn/rhn_server_xmlrpc.log"
     ])
+    rhn_taskomatic_daemon_log = first_file(["/var/log/rhn/rhn_taskomatic_daemon.log",
+                                               "rhn-logs/rhn/rhn_taskomatic_daemon.log"])
     rhosp_release = simple_file("/etc/rhosp-release")
     root_crontab = first_file(["sos_commands/crontab/root_crontab", "sos_commands/cron/root_crontab"])
     route = simple_file("sos_commands/networking/route_-n")
@@ -262,6 +273,7 @@ class SosSpecs(Specs):
     vdsm_import_log = glob_file("var/log/vdsm/import/import-*.log")
     vgdisplay = first_file(["sos_commands/lvm2/vgdisplay_-vv_--config_global_locking_type_0", "sos_commands/lvm2/vgdisplay_-vv"])
     vgs = first_file(["sos_commands/lvm2/vgs_-v_-o_vg_mda_count_vg_mda_free_vg_mda_size_vg_mda_used_count_vg_tags_--config_global_locking_type_0", "sos_commands/lvm2/vgs_-v", "sos_commands/devicemapper/vgs_-v"])
+    virsh_list_all = simple_file("sos_commands/virsh/virsh_-r_list_--all")
     vmcore_dmesg = glob_file("/var/crash/*/vmcore-dmesg.txt")
     vmware_tools_conf = simple_file("etc/vmware-tools/tools.conf")
     xfs_info = glob_file("sos_commands/xfs/xfs_info*")
